.. _using-index:

###################
Working with BigJob
###################


This part of the documentation is devoted to general information on the setup
and configuration of BigJob and things that make working with BigJob easier.

.. toctree::

   cmdtools.rst
   logging.rst
   output.rst
